@@ -1,5 +1,5 @@
 // Netify Agent
-// Copyright (C) 2015-2018 eGloo Incorporated <http://www.egloo.ca>
+// Copyright (C) 2015-2019 eGloo Incorporated <http://www.egloo.ca>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,12 +24,12 @@
 #include <unordered_map>
 #ifdef HAVE_ATOMIC
 #include <atomic>
-#else
-typedef bool atomic_bool;
 #endif
+#include <regex>
 
 #include <unistd.h>
 #include <stdlib.h>
+#include <string.h>
 #include <signal.h>
 #include <pthread.h>
 #include <dlfcn.h>
@@ -39,6 +39,7 @@ typedef bool atomic_bool;
 #include <sys/socket.h>
 
 #include <json.h>
+#include <pcap/pcap.h>
 
 using namespace std;
 
