@@ -134,7 +134,8 @@ static int ndSinkThread_progress(void *user,
 
 ndSinkThread::ndSinkThread()
     : ndThread("nd-sink", -1),
-    headers(NULL), headers_gz(NULL), pending_size(0), post_errors(0)
+    headers(NULL), headers_gz(NULL), pending_size(0), post_errors(0),
+    update_imf(1), update_count(0)
 {
     int rc;
 
@@ -246,6 +247,11 @@ void *ndSinkThread::Entry(void)
         }
 
         do {
+            if (! ND_UPLOAD_ENABLED) {
+                pending.clear();
+                pending_size = 0;
+            }
+
             if (uploads.front().size() <= ND_COMPRESS_SIZE)
                 pending.push_back(make_pair(false, uploads.front()));
             else
@@ -289,6 +295,10 @@ void ndSinkThread::QueuePush(const string &json)
 
     Lock();
 
+    if (! ND_UPLOAD_ENABLED) {
+        while (! uploads.empty()) uploads.pop();
+    }
+
     uploads.push(json);
 
     if ((rc = pthread_cond_broadcast(&uploads_cond)) != 0)
@@ -437,6 +447,14 @@ void ndSinkThread::Upload(void)
         post_errors = 0;
     }
 
+    if (++update_count == update_imf || post_errors > 0)
+        update_count = 0;
+    else {
+        nd_debug_printf("%s: payload upload delay: %u of %u\n",
+            tag.c_str(), update_count, update_imf);
+        return;
+    }
+
     do {
         nd_debug_printf("%s: payload %lu/%lu (%d of %d bytes)...\n",
             tag.c_str(), ++xfer, total, pending.front().second.size(), pending_size);
@@ -617,6 +635,9 @@ void ndSinkThread::ProcessResponse(void)
         if (response == NULL)
             throw runtime_error(strerror(ENOMEM));
 
+        response->update_imf = update_imf;
+        response->upload_enabled = ND_UPLOAD_ENABLED;
+
         response->Parse(body_data);
 
         if (response->resp_code == ndJSON_RESP_OK) {
@@ -659,6 +680,24 @@ void ndSinkThread::ProcessResponse(void)
 
             if (create_headers) CreateHeaders();
         }
+
+        if (response->update_imf > 0 && response->update_imf != update_imf) {
+            nd_debug_printf("%s: changing update multiplier from: %u"
+                " to: %u\n", tag.c_str(), update_imf, response->update_imf);
+            update_imf = response->update_imf;
+        }
+
+        if (response->upload_enabled != (ND_UPLOAD_ENABLED > 0)) {
+
+            if (response->upload_enabled)
+                nd_config.flags |= ndGF_UPLOAD_ENABLED;
+            else
+                nd_config.flags &= ~ndGF_UPLOAD_ENABLED;
+
+            nd_printf("%s: payload uploads: %s\n",
+                tag.c_str(), ND_UPLOAD_ENABLED ? "enabled" : "disabled");
+        }
+
     } catch (ndJsonParseException &e) {
         response->resp_code = ndJSON_RESP_PARSE_ERROR;
         response->resp_message = e.what();
